# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from systemathics.apis.services.static_data.v1 import set_static_data_pb2 as systemathics_dot_apis_dot_services_dot_static__data_dot_v1_dot_set__static__data__pb2


class SetStaticDataServiceStub(object):
    """Called to set static data.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateCdsIndexOption = channel.unary_unary(
                '/systemathics.apis.services.static_data.v1.SetStaticDataService/CreateCdsIndexOption',
                request_serializer=systemathics_dot_apis_dot_services_dot_static__data_dot_v1_dot_set__static__data__pb2.CreateCdsIndexOptionRequest.SerializeToString,
                response_deserializer=systemathics_dot_apis_dot_services_dot_static__data_dot_v1_dot_set__static__data__pb2.CdsIndexOptionIdResponse.FromString,
                )
        self.GetCdsIndexOption = channel.unary_unary(
                '/systemathics.apis.services.static_data.v1.SetStaticDataService/GetCdsIndexOption',
                request_serializer=systemathics_dot_apis_dot_services_dot_static__data_dot_v1_dot_set__static__data__pb2.CdsIndexOptionIdRequest.SerializeToString,
                response_deserializer=systemathics_dot_apis_dot_services_dot_static__data_dot_v1_dot_set__static__data__pb2.CdsIndexOptionIdResponse.FromString,
                )
        self.GetAllCdsIndexOption = channel.unary_stream(
                '/systemathics.apis.services.static_data.v1.SetStaticDataService/GetAllCdsIndexOption',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=systemathics_dot_apis_dot_services_dot_static__data_dot_v1_dot_set__static__data__pb2.CdsIndexOptionIdResponse.FromString,
                )
        self.UpdateCdsIndexOption = channel.unary_unary(
                '/systemathics.apis.services.static_data.v1.SetStaticDataService/UpdateCdsIndexOption',
                request_serializer=systemathics_dot_apis_dot_services_dot_static__data_dot_v1_dot_set__static__data__pb2.UpdateCdsIndexOptionRequest.SerializeToString,
                response_deserializer=systemathics_dot_apis_dot_services_dot_static__data_dot_v1_dot_set__static__data__pb2.CdsIndexOptionIdResponse.FromString,
                )
        self.DeleteCdsIndexOption = channel.unary_unary(
                '/systemathics.apis.services.static_data.v1.SetStaticDataService/DeleteCdsIndexOption',
                request_serializer=systemathics_dot_apis_dot_services_dot_static__data_dot_v1_dot_set__static__data__pb2.CdsIndexOptionIdRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )


class SetStaticDataServiceServicer(object):
    """Called to set static data.
    """

    def CreateCdsIndexOption(self, request, context):
        """Create Cds Index Option Static data 
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCdsIndexOption(self, request, context):
        """Get Cds Index Option Static data by Id
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAllCdsIndexOption(self, request, context):
        """Get all Cds Index Option Static data
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateCdsIndexOption(self, request, context):
        """Update Cds Index Option Static data by Id
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteCdsIndexOption(self, request, context):
        """Get Option Static data from OTC Streaming by Id
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SetStaticDataServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateCdsIndexOption': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateCdsIndexOption,
                    request_deserializer=systemathics_dot_apis_dot_services_dot_static__data_dot_v1_dot_set__static__data__pb2.CreateCdsIndexOptionRequest.FromString,
                    response_serializer=systemathics_dot_apis_dot_services_dot_static__data_dot_v1_dot_set__static__data__pb2.CdsIndexOptionIdResponse.SerializeToString,
            ),
            'GetCdsIndexOption': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCdsIndexOption,
                    request_deserializer=systemathics_dot_apis_dot_services_dot_static__data_dot_v1_dot_set__static__data__pb2.CdsIndexOptionIdRequest.FromString,
                    response_serializer=systemathics_dot_apis_dot_services_dot_static__data_dot_v1_dot_set__static__data__pb2.CdsIndexOptionIdResponse.SerializeToString,
            ),
            'GetAllCdsIndexOption': grpc.unary_stream_rpc_method_handler(
                    servicer.GetAllCdsIndexOption,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=systemathics_dot_apis_dot_services_dot_static__data_dot_v1_dot_set__static__data__pb2.CdsIndexOptionIdResponse.SerializeToString,
            ),
            'UpdateCdsIndexOption': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateCdsIndexOption,
                    request_deserializer=systemathics_dot_apis_dot_services_dot_static__data_dot_v1_dot_set__static__data__pb2.UpdateCdsIndexOptionRequest.FromString,
                    response_serializer=systemathics_dot_apis_dot_services_dot_static__data_dot_v1_dot_set__static__data__pb2.CdsIndexOptionIdResponse.SerializeToString,
            ),
            'DeleteCdsIndexOption': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteCdsIndexOption,
                    request_deserializer=systemathics_dot_apis_dot_services_dot_static__data_dot_v1_dot_set__static__data__pb2.CdsIndexOptionIdRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'systemathics.apis.services.static_data.v1.SetStaticDataService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class SetStaticDataService(object):
    """Called to set static data.
    """

    @staticmethod
    def CreateCdsIndexOption(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/systemathics.apis.services.static_data.v1.SetStaticDataService/CreateCdsIndexOption',
            systemathics_dot_apis_dot_services_dot_static__data_dot_v1_dot_set__static__data__pb2.CreateCdsIndexOptionRequest.SerializeToString,
            systemathics_dot_apis_dot_services_dot_static__data_dot_v1_dot_set__static__data__pb2.CdsIndexOptionIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCdsIndexOption(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/systemathics.apis.services.static_data.v1.SetStaticDataService/GetCdsIndexOption',
            systemathics_dot_apis_dot_services_dot_static__data_dot_v1_dot_set__static__data__pb2.CdsIndexOptionIdRequest.SerializeToString,
            systemathics_dot_apis_dot_services_dot_static__data_dot_v1_dot_set__static__data__pb2.CdsIndexOptionIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAllCdsIndexOption(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/systemathics.apis.services.static_data.v1.SetStaticDataService/GetAllCdsIndexOption',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            systemathics_dot_apis_dot_services_dot_static__data_dot_v1_dot_set__static__data__pb2.CdsIndexOptionIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateCdsIndexOption(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/systemathics.apis.services.static_data.v1.SetStaticDataService/UpdateCdsIndexOption',
            systemathics_dot_apis_dot_services_dot_static__data_dot_v1_dot_set__static__data__pb2.UpdateCdsIndexOptionRequest.SerializeToString,
            systemathics_dot_apis_dot_services_dot_static__data_dot_v1_dot_set__static__data__pb2.CdsIndexOptionIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteCdsIndexOption(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/systemathics.apis.services.static_data.v1.SetStaticDataService/DeleteCdsIndexOption',
            systemathics_dot_apis_dot_services_dot_static__data_dot_v1_dot_set__static__data__pb2.CdsIndexOptionIdRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
